summaryrefslogtreecommitdiffstats
path: root/kcontrol/joystick/joystick.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol/joystick/joystick.cpp')
-rw-r--r--kcontrol/joystick/joystick.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kcontrol/joystick/joystick.cpp b/kcontrol/joystick/joystick.cpp
index 69e81b79b..d0521d81e 100644
--- a/kcontrol/joystick/joystick.cpp
+++ b/kcontrol/joystick/joystick.cpp
@@ -1,7 +1,7 @@
/***************************************************************************
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
* This file is part of the TDE Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
@@ -70,7 +70,7 @@ joystick::joystick(TQWidget *parent, const char *name, const TQStringList &)
: TDECModule(JoystickFactory::instance(), parent, name)
{
setAboutData( new TDEAboutData("kcmjoystick", I18N_NOOP("TDE Joystick Control Module"), "1.0",
- I18N_NOOP("TDE Control Center Module to test Joysticks"),
+ I18N_NOOP("Trinity Control Center Module to test Joysticks"),
TDEAboutData::License_GPL, "(c) 2004, Martin Koller",
0, "m.koller@surfeu.at"));
@@ -1,7 +1,7 @@
* Copyright (C) 2003 by Martin Koller *
* m.koller@surfeu.at *
- * This file is part of the TDE Control Center Module for Joysticks *
+ * This file is part of the Trinity Control Center Module for Joysticks *
* *
* This program is free software; you can redistribute it and/or modify *